#
# spec file for package perl-XML-Feed
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-Feed
Name:           perl-XML-Feed
Version:        0.63
Release:        1.15
Summary:        Syndication feed parser and auto-discovery
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DAVECROSS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::ErrorHandler)
BuildRequires:  perl(DateTime)
BuildRequires:  perl(DateTime::Format::Flexible)
BuildRequires:  perl(DateTime::Format::ISO8601)
BuildRequires:  perl(DateTime::Format::Mail)
BuildRequires:  perl(DateTime::Format::Natural)
BuildRequires:  perl(DateTime::Format::W3CDTF)
BuildRequires:  perl(Feed::Find)
BuildRequires:  perl(HTML::Entities)
BuildRequires:  perl(HTML::TokeParser)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Module::Build) >= 0.420000
BuildRequires:  perl(Module::Pluggable)
BuildRequires:  perl(URI)
BuildRequires:  perl(URI::Fetch)
BuildRequires:  perl(XML::Atom) >= 0.38
BuildRequires:  perl(XML::LibXML) >= 1.66
BuildRequires:  perl(XML::RSS) >= 1.47
BuildRequires:  perl(XML::XPath)
Requires:       perl(Class::ErrorHandler)
Requires:       perl(DateTime)
Requires:       perl(DateTime::Format::Flexible)
Requires:       perl(DateTime::Format::ISO8601)
Requires:       perl(DateTime::Format::Mail)
Requires:       perl(DateTime::Format::Natural)
Requires:       perl(DateTime::Format::W3CDTF)
Requires:       perl(Feed::Find)
Requires:       perl(HTML::Entities)
Requires:       perl(HTML::TokeParser)
Requires:       perl(LWP::UserAgent)
Requires:       perl(Module::Pluggable)
Requires:       perl(URI::Fetch)
Requires:       perl(XML::Atom) >= 0.38
Requires:       perl(XML::LibXML) >= 1.66
Requires:       perl(XML::RSS) >= 1.47
%{perl_requires}

%description
_XML::Feed_ is a syndication feed parser for both RSS and Atom feeds. It
also implements feed auto-discovery for finding feeds, given a URI.

_XML::Feed_ supports the following syndication feed formats:

* * RSS 0.91

* * RSS 1.0

* * RSS 2.0

* * Atom

The goal of _XML::Feed_ is to provide a unified API for parsing and using
the various syndication formats. The different flavors of RSS and Atom
handle data in different ways: date handling; summaries and content;
escaping and quoting; etc. This module attempts to remove those differences
by providing a wrapper around the formats and the classes implementing
those formats (XML::RSS and XML::Atom::Feed). For example, dates are
handled differently in each of the above formats. To provide a unified API
for date handling, _XML::Feed_ converts all date formats transparently into
DateTime objects, which it then returns to the caller.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog.md Changes README

%changelog
* Wed May 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.63
  see /usr/share/doc/packages/perl-XML-Feed/ChangeLog.md
  [#]# [0.63] - 2021-05-25
  [#]## Fixed
  * Fixed a bug with non-UTC time zones (thanks @nanto)
  [#]# [0.62] - 2021-05-24
  [#]## Fixed
  * Fixed a broken constructor call (thanks @bbkr)
  * Reduced some code complexity
  [#]## Added
  * Added an explicit "use" statement
* Fri Jan 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.61
  see /usr/share/doc/packages/perl-XML-Feed/ChangeLog.md
  [#]# [0.61] - 2021-01-28
  [#]## Fixed
  * Reformated Build.PL
* Fri Jan 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.60
  see /usr/share/doc/packages/perl-XML-Feed/ChangeLog.md
* Thu Feb  7 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.59
  see /usr/share/doc/packages/perl-XML-Feed/Changes
  2019-02-06  Dave Cross <dave@dave.org.uk>
  * lib/XML/Feed.pm, lib/XML/Feed/Content.pm, lib/XML/Feed/Enclosure.pm,
    lib/XML/Feed/Entry.pm, lib/XML/Feed/Entry/Format/Atom.pm,
    lib/XML/Feed/Entry/Format/RSS.pm, lib/XML/Feed/Format/Atom.pm,
    lib/XML/Feed/Format/RSS.pm, lib/XML/Feed/Util.pm: Bump version for release
  * MANIFEST: Added missing files to MANIFEST
* Wed Feb  6 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.58
  see /usr/share/doc/packages/perl-XML-Feed/Changes
  2019-02-05  Dave Cross <dave@dave.org.uk>
  * lib/XML/Feed.pm, lib/XML/Feed/Content.pm,
  lib/XML/Feed/Enclosure.pm, lib/XML/Feed/Entry.pm,
  lib/XML/Feed/Entry/Format/Atom.pm,
  lib/XML/Feed/Entry/Format/RSS.pm, lib/XML/Feed/Format/Atom.pm,
  lib/XML/Feed/Format/RSS.pm, lib/XML/Feed/Util.pm: Bump version
  * t/12-multi-categories-atom.t, t/12-multi-categories-rss.t, t/12
  - multi-subjects-rss.t: Don't hard-code 'require' paths.
* Tue Feb  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.57
  see /usr/share/doc/packages/perl-XML-Feed/Changes
  2019-02-04  Dave Cross <dave@dave.org.uk>
  * lib/XML/Feed.pm, lib/XML/Feed/Content.pm,
  lib/XML/Feed/Enclosure.pm, lib/XML/Feed/Entry.pm,
  lib/XML/Feed/Entry/Format/Atom.pm,
  lib/XML/Feed/Entry/Format/RSS.pm, lib/XML/Feed/Format/Atom.pm,
  lib/XML/Feed/Format/RSS.pm, lib/XML/Feed/Util.pm: Bump versions for
  release.
  2019-02-04  Mohammad S Anwar <mohammad.anwar@yahoo.com>
  * Build.PL: Fixed github repo meta not showing up.
  2019-02-04  Dave Cross <dave@dave.org.uk>
  * Changes: Update Changes
  2019-02-03  Dave Cross <dave@dave.org.uk>
  * eg/check_feed.pl: Improve one of the example programs
  * t/29-date-parsing.t: Improved tests
  2019-01-11  Nicolas R <atoomic@cpan.org>
  * MANIFEST, t/relative-links.t: Add a unit test for relative links
  RT 53661 - GH #45  This is adding a unit test from an upstream
  ticket. Not really a bug, more a question about behavior and
  relative links.  Make sure we are processing correctly.
  2019-01-11  Dave Cross <dave@dave.org.uk>
  * lib/XML/Feed.pm, lib/XML/Feed/Content.pm,
  lib/XML/Feed/Enclosure.pm, lib/XML/Feed/Entry.pm,
  lib/XML/Feed/Entry/Format/Atom.pm,
  lib/XML/Feed/Entry/Format/RSS.pm, lib/XML/Feed/Format/Atom.pm,
  lib/XML/Feed/Format/RSS.pm, lib/XML/Feed/Util.pm: Bump version
  numbers
  2019-01-11  Nicolas R <atoomic@cpan.org>
  * Build.PL: Advertise GitHub as default bugtracker  Also set repo url
  and web entries
  2019-01-10  Nicolas R <atoomic@cpan.org>
  * .travis.yml: add Perl 5.22 to 5.26 to travis
  2018-10-28  Tim Gim Yee <tim.gim.yee@gmail.com>
  * lib/XML/Feed/Util.pm: Rename undocumented private subroutine for
  Pod::Coverage
  2018-10-26  Tim Gim Yee <tim.gim.yee@gmail.com>
  * Build.PL, MANIFEST, MANIFEST.SKIP,
  lib/XML/Feed/Entry/Format/Atom.pm,
  lib/XML/Feed/Entry/Format/RSS.pm, lib/XML/Feed/Format/Atom.pm,
  lib/XML/Feed/Format/RSS.pm, lib/XML/Feed/Util.pm, t/29-date-
  parsing.t, t/samples/rss10-invalid-date.xml: Parse incorrectly
  formatted dates
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.55
  see /usr/share/doc/packages/perl-XML-Feed/Changes
* Tue Dec 15 2015 coolo@suse.com
- updated to 0.53
  see /usr/share/doc/packages/perl-XML-Feed/Changes
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.52
  see /usr/share/doc/packages/perl-XML-Feed/Changes
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.46
  see /usr/share/doc/packages/perl-XML-Feed/Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Jul 22 2008 guru@unixtech.be
- new package
